{
  inputs,
  lib,
  pkgs,
  ...
}:

{
  imports = [
    inputs.disko.nixosModules.disko
    ./hardware-configuration.nix
    ./disko-config.nix
    ../desktop.nix
  ];

  nixpkgs = {
    hostPlatform = "x86_64-linux";
    config = {
      allowUnfree = true;
      nvidia.acceptLicense = true;
    };
  };

  boot.loader = {
    systemd-boot.enable = true;
    efi.canTouchEfiVariables = true;
  };

  networking.hostId = "cf791898";

  # nvidia 470 driver doesn't work with Wayland
  services = {
    xserver = {
      displayManager.gdm.wayland = lib.mkForce false;
      videoDrivers = [ "nvidia" ];
    };
    displayManager = {
      defaultSession = "gnome-xorg";
    };
  };

  # Workaround for label rendering bug in GTK4 with nvidia 470 driver
  environment.sessionVariables.GSK_RENDERER = "gl";

  environment.systemPackages = [
    pkgs.moonlight-qt
  ];

  system.stateVersion = "22.11";
}
